@@ -158,6 +158,10 @@ DICT_METRICS.add(metric_name="base_gps_distance_delta", type_=np.float64)
 DICT_METRICS.add(metric_name="base_gps_distance_delta", data_place_str="druid", raw_name="base_gps_distance_delta")
 DICT_METRICS.add(metric_name="base_gps_distance_delta", data_place_str="fetch", raw_name="deltaGpsDistance", module=GPS_BASE_MODULE)
 
+DICT_METRICS.add(metric_name="base_curve_radius", type_=np.float64)
+DICT_METRICS.add(metric_name="base_curve_radius", data_place_str="druid", raw_name="base_curve_radius")
+DICT_METRICS.add(metric_name="base_curve_radius", data_place_str="fetch", raw_name="curveRadius", module=GPS_BASE_MODULE)
+
 DICT_METRICS.add(metric_name="base_curve_status", type_=str)
 DICT_METRICS.add(metric_name="base_curve_status", data_place_str="druid", raw_name="base_curve_status")
 DICT_METRICS.add(metric_name="base_curve_status", data_place_str="fetch", raw_name="curveRadiusCategory", module=GPS_BASE_MODULE)
@@ -175,6 +179,7 @@ DICT_METRICS.add(metric_name="base_gps_accelerometer_lat", data_place_str="druid
 DICT_METRICS.add(metric_name="base_gps_accelerometer_lat", data_place_str="fetch", raw_name="gpsAccX", module=GPS_BASE_MODULE)
 
 DICT_METRICS.add(metric_name="base_gps_accelerometer_lng", type_=np.float64, target_type_=np.int64)
+DICT_METRICS.add(metric_name="base_gps_accelerometer_lng", data_place_str="druid", raw_name="base_gps_accelerometer_lng")
 DICT_METRICS.add(metric_name="base_gps_accelerometer_lng", data_place_str="fetch", raw_name="gpsAccY", module=GPS_BASE_MODULE)
 
 DICT_METRICS.add(metric_name="daycycle_alt", type_=np.float64)
@@ -193,6 +198,23 @@ DICT_METRICS.add(metric_name="base_gps_speed", type_=np.float64)
 DICT_METRICS.add(metric_name="base_gps_speed", data_place_str="druid", raw_name="base_gps_speed")
 DICT_METRICS.add(metric_name="base_gps_speed", data_place_str="fetch", raw_name="gpsSpeed", module=GPS_BASE_MODULE)
 
+DICT_METRICS.add(metric_name="raw_gps_satellites", type_=np.int64)
+DICT_METRICS.add(metric_name="raw_gps_satellites", data_place_str="druid", raw_name="raw_gps_satellites")
+DICT_METRICS.add(metric_name="raw_gps_satellites", data_place_str="fetch", raw_name="nbSats", module=GPS_BASE_MODULE)
+
+DICT_METRICS.add(metric_name="raw_gps_hdop", type_=np.int64)
+DICT_METRICS.add(metric_name="raw_gps_hdop", data_place_str="druid", raw_name="raw_gps_hdop")
+DICT_METRICS.add(metric_name="raw_gps_hdop", data_place_str="fetch", raw_name="hdop", module=GPS_BASE_MODULE)
+
+DICT_METRICS.add(metric_name="high_frequency_acc_x", type_=str)
+DICT_METRICS.add(metric_name="high_frequency_acc_x", data_place_str="fetch", raw_name="highFrequencyAccX", module=GPS_BASE_MODULE)
+
+DICT_METRICS.add(metric_name="high_frequency_acc_y", type_=str)
+DICT_METRICS.add(metric_name="high_frequency_acc_y", data_place_str="fetch", raw_name="highFrequencyAccY", module=GPS_BASE_MODULE)
+
+DICT_METRICS.add(metric_name="high_frequency_acc_z", type_=str)
+DICT_METRICS.add(metric_name="high_frequency_acc_z", data_place_str="fetch", raw_name="highFrequencyAccZ", module=GPS_BASE_MODULE)
+
 DICT_METRICS.add(metric_name="raw_gps_heading", type_=np.float64)
 DICT_METRICS.add(metric_name="raw_gps_heading", data_place_str="druid", raw_name="raw_gps_heading")
 DICT_METRICS.add(metric_name="raw_gps_heading", data_place_str="fetch", raw_name="azimuth", module=GPS_BASE_MODULE)
@@ -219,7 +241,7 @@ DICT_METRICS.add(metric_name="map_route_duration_sum", type_=np.float64)
 DICT_METRICS.add(metric_name="map_route_duration_sum", data_place_str="druid", raw_name="map_route_duration_sum")
 DICT_METRICS.add(metric_name="map_route_duration_sum", data_place_str="fetch", raw_name="accumulatedMapMatchDuration", module=CARTO_MODULE)
 
-DICT_METRICS.add(metric_name="map_route_status", type_=np.float64)
+DICT_METRICS.add(metric_name="map_route_status", type_=str)
 DICT_METRICS.add(metric_name="map_route_status", data_place_str="druid", raw_name="map_route_status")
 DICT_METRICS.add(metric_name="map_route_status", data_place_str="fetch", raw_name="matchType", module=CARTO_MODULE)
 
@@ -239,7 +261,7 @@ DICT_METRICS.add(metric_name="map_gps_lng", type_=np.float64)
 DICT_METRICS.add(metric_name="map_gps_lng", data_place_str="druid", raw_name="map_gps_lng")
 DICT_METRICS.add(metric_name="map_gps_lng", data_place_str="fetch", raw_name="map.gps.lng", module=CARTO_MODULE)
 
-DICT_METRICS.add(metric_name="map_road_curve_status", type_=np.float64)
+DICT_METRICS.add(metric_name="map_road_curve_status", type_=str)
 DICT_METRICS.add(metric_name="map_road_curve_status", data_place_str="druid", raw_name="map_road_curve_status")
 DICT_METRICS.add(metric_name="map_road_curve_status", data_place_str="fetch", raw_name="map.route.curve.status", module=CARTO_MODULE)
 
@@ -247,6 +269,7 @@ DICT_METRICS.add(metric_name="map_match_azimuth", type_=np.float64)
 DICT_METRICS.add(metric_name="map_match_azimuth", data_place_str="fetch", raw_name="mapMatchAzimuth", module=CARTO_MODULE)
 
 DICT_METRICS.add(metric_name="map_road_curve_radius", type_=np.float64)
+DICT_METRICS.add(metric_name="map_road_curve_radius", data_place_str="druid", raw_name="map_road_curve_radius")
 DICT_METRICS.add(metric_name="map_road_curve_radius", data_place_str="fetch", raw_name="mapMatchCurveRadius", module=CARTO_MODULE)
 
 DICT_METRICS.add(metric_name="map_route_altitude", type_=np.float64)
@@ -257,7 +280,7 @@ DICT_METRICS.add(metric_name="map_match_gps_speed", data_place_str="fetch", raw_
 
 
 # LanduseModule
-DICT_METRICS.add(metric_name="landuse_osm_id", type_=np.int64)
+DICT_METRICS.add(metric_name="landuse_osm_id", type_=np.float64, target_type_=np.int64)
 DICT_METRICS.add(metric_name="landuse_osm_id", data_place_str="fetch", raw_name="landuseOsmId", module=LANDUSE_MODULE)
 
 DICT_METRICS.add(metric_name="landuse_osm_type", type_=str)
@@ -269,8 +292,11 @@ DICT_METRICS.add(metric_name="map_landuse", data_place_str="fetch", raw_name="la
 
 
 # ElevationModule
+DICT_METRICS.add(metric_name="slope", type_=np.float64)
+DICT_METRICS.add(metric_name="slope", data_place_str="fetch", raw_name="slope", module=ELEVATION_MODULE)
+
 DICT_METRICS.add(metric_name="slope_category", type_=str)
-DICT_METRICS.add(metric_name="slope_category", data_place_str="fetch", raw_name="map.route.slope.category", module=ELEVATION_MODULE)
+DICT_METRICS.add(metric_name="slope_category", data_place_str="fetch", raw_name="slope.category", module=ELEVATION_MODULE)
 
 DICT_METRICS.add(metric_name="altitude", type_=np.float64)
 DICT_METRICS.add(metric_name="altitude", data_place_str="fetch", raw_name="altitude", module=ELEVATION_MODULE)
@@ -298,16 +324,12 @@ DICT_METRICS.add(metric_name="base_gps_distance_sum", data_place_str="fetch", ra
 
 
 # Druid
-DICT_METRICS.add(metric_name="raw_gps_satellites", type_=str)
-DICT_METRICS.add(metric_name="raw_gps_satellites", data_place_str="druid", raw_name="raw_gps_satellites")
-
 DICT_METRICS.add(metric_name="raw_sensor_odometer", type_=str)
 DICT_METRICS.add(metric_name="raw_sensor_odometer", data_place_str="druid", raw_name="raw_sensor_odometerv")
 
 DICT_METRICS.add(metric_name="recurrent_trip_id", type_=str)
 DICT_METRICS.add(metric_name="recurrent_trip_id", data_place_str="druid", raw_name="recurrent_trip_id")
 
-
 DICT_METRICS.add(metric_name="score_map_route_distance_exactness", type_=np.float64)
 DICT_METRICS.add(metric_name="score_map_route_distance_exactness", data_place_str="druid", raw_name="score_map_route_distance_exactness")
 
@@ -332,17 +354,12 @@ DICT_METRICS.add(metric_name="score_raw_path_exactness", data_place_str="druid",
 DICT_METRICS.add(metric_name="score_raw_path_precision", type_=np.float64)
 DICT_METRICS.add(metric_name="score_raw_path_precision", data_place_str="druid", raw_name="score_raw_path_precision")
 
-
 DICT_METRICS.add(metric_name="raw_gps_accuracy", type_=np.float64)
 DICT_METRICS.add(metric_name="raw_gps_accuracy", data_place_str="druid", raw_name="raw_gps_accuracy")
 
 DICT_METRICS.add(metric_name="raw_gps_coordinates", type_=str)
 DICT_METRICS.add(metric_name="raw_gps_coordinates", data_place_str="druid", raw_name="raw_gps_coordinates")
 
-DICT_METRICS.add(metric_name="raw_gps_hdop", type_=np.float64)
-DICT_METRICS.add(metric_name="raw_gps_hdop", data_place_str="druid", raw_name="raw_gps_hdop")
-
-
 DICT_METRICS.add(metric_name="map_road_bridge", type_=bool)
 DICT_METRICS.add(metric_name="map_road_bridge", data_place_str="druid", raw_name="map_road_bridge")
 
@@ -369,9 +386,6 @@ DICT_METRICS.add(metric_name="map_road_density", data_place_str="druid", raw_nam
 DICT_METRICS.add(metric_name="map_elevation", type_=str)
 DICT_METRICS.add(metric_name="map_elevation", data_place_str="druid", raw_name="map_elevation")
 
-DICT_METRICS.add(metric_name="base_curve_radius", type_=np.float64)
-DICT_METRICS.add(metric_name="base_curve_radius", data_place_str="druid", raw_name="base_curve_radius")
-
 DICT_METRICS.add(metric_name="daycycle_heading", type_=np.int64)
 DICT_METRICS.add(metric_name="daycycle_heading", data_place_str="druid", raw_name="daycycle_heading")
 
